@@ -20,6 +20,13 @@ void WebPage::javaScriptConsoleMessage(const QString &message, int lineNumber, c
     qDebug() << sourceId << ":" << lineNumber << ": " << message;
 }
 
+#ifdef Q_WS_MAEMO_5
+QString WebPage::userAgentForUrl(const QUrl &url) const {
+
+    return QWebPage::userAgentForUrl(url).append(" Maemo"); // add hint for useragent.js
+}
+#endif
+
 bool WebPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request,
                                       QWebPage::NavigationType type) {
 
